package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.CloudDiskServicesMapper;
import com.zyc.system.domain.CloudDiskServices;
import com.zyc.system.service.ICloudDiskServicesService;

/**
 * 云硬盘存储服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class CloudDiskServicesServiceImpl implements ICloudDiskServicesService 
{
    @Autowired
    private CloudDiskServicesMapper cloudDiskServicesMapper;

    /**
     * 查询云硬盘存储服务
     * 
     * @param id 云硬盘存储服务主键
     * @return 云硬盘存储服务
     */
    @Override
    public CloudDiskServices selectCloudDiskServicesById(Integer id)
    {
        return cloudDiskServicesMapper.selectCloudDiskServicesById(id);
    }

    /**
     * 查询云硬盘存储服务列表
     * 
     * @param cloudDiskServices 云硬盘存储服务
     * @return 云硬盘存储服务
     */
    @Override
    public List<CloudDiskServices> selectCloudDiskServicesList(CloudDiskServices cloudDiskServices)
    {
        return cloudDiskServicesMapper.selectCloudDiskServicesList(cloudDiskServices);
    }

    /**
     * 新增云硬盘存储服务
     * 
     * @param cloudDiskServices 云硬盘存储服务
     * @return 结果
     */
    @Override
    public int insertCloudDiskServices(CloudDiskServices cloudDiskServices)
    {
        return cloudDiskServicesMapper.insertCloudDiskServices(cloudDiskServices);
    }

    /**
     * 修改云硬盘存储服务
     * 
     * @param cloudDiskServices 云硬盘存储服务
     * @return 结果
     */
    @Override
    public int updateCloudDiskServices(CloudDiskServices cloudDiskServices)
    {
        return cloudDiskServicesMapper.updateCloudDiskServices(cloudDiskServices);
    }

    /**
     * 批量删除云硬盘存储服务
     * 
     * @param ids 需要删除的云硬盘存储服务主键
     * @return 结果
     */
    @Override
    public int deleteCloudDiskServicesByIds(Integer[] ids)
    {
        return cloudDiskServicesMapper.deleteCloudDiskServicesByIds(ids);
    }

    /**
     * 删除云硬盘存储服务信息
     * 
     * @param id 云硬盘存储服务主键
     * @return 结果
     */
    @Override
    public int deleteCloudDiskServicesById(Integer id)
    {
        return cloudDiskServicesMapper.deleteCloudDiskServicesById(id);
    }
}
