package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.CloudDiskServices;
import com.zyc.system.service.ICloudDiskServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 云硬盘存储服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/CloudDiskServicesController")
public class CloudDiskServicesController extends BaseController
{
    @Autowired
    private ICloudDiskServicesService cloudDiskServicesService;

    /**
     * 查询云硬盘存储服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(CloudDiskServices cloudDiskServices)
    {
        startPage();
        List<CloudDiskServices> list = cloudDiskServicesService.selectCloudDiskServicesList(cloudDiskServices);
        return getDataTable(list);
    }

    /**
     * 导出云硬盘存储服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "云硬盘存储服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CloudDiskServices cloudDiskServices)
    {
        List<CloudDiskServices> list = cloudDiskServicesService.selectCloudDiskServicesList(cloudDiskServices);
        ExcelUtil<CloudDiskServices> util = new ExcelUtil<CloudDiskServices>(CloudDiskServices.class);
        util.exportExcel(response, list, "云硬盘存储服务数据");
    }

    /**
     * 获取云硬盘存储服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(cloudDiskServicesService.selectCloudDiskServicesById(id));
    }

    /**
     * 新增云硬盘存储服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "云硬盘存储服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CloudDiskServices cloudDiskServices)
    {
        return toAjax(cloudDiskServicesService.insertCloudDiskServices(cloudDiskServices));
    }

    /**
     * 修改云硬盘存储服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "云硬盘存储服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CloudDiskServices cloudDiskServices)
    {
        return toAjax(cloudDiskServicesService.updateCloudDiskServices(cloudDiskServices));
    }

    /**
     * 删除云硬盘存储服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "云硬盘存储服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(cloudDiskServicesService.deleteCloudDiskServicesByIds(ids));
    }
}
